PropertiesBuf

Struct PropertiesBuf 

pub struct PropertiesBuf<P: PropertyConstraint> {
    _marker: PhantomData<P>,
    bytes: Vec<u8>,
}
Available on crate feature alloc only.
Owned property bytes, the owned counterpart to Properties<P>.

Fields

_marker: PhantomData<P>bytes: Vec<u8>

Implementations



impl<P: PropertyConstraint> PropertiesBuf<P>

pub const fn new() -> Self

Creates an empty property buffer.

pub const fn as_properties(&self) -> &Properties<P>

Returns a reference to the underlying Properties<P>.

pub fn push(&mut self, prop: Property<'_>) -> Result<(), PropertiesBufError>

Appends a property to the buffer.

Errors

Returns PropertiesBufError::DisallowedProperty if the property’s identifier is not in P::ALLOWED, or PropertiesBufError::TooLong if appending would exceed Vbi::MAX.

pub fn try_extend<'a>( &mut self, iter: impl IntoIterator<Item = Property<'a>>, ) -> Result<(), PropertiesBufError>

Extends this buffer with all properties from an iterator.

Errors

Returns PropertiesBufError on the first disallowed or over-length property. Properties pushed before the error remain.

pub fn try_from_iter<'a>( iter: impl IntoIterator<Item = Property<'a>>, ) -> Result<Self, PropertiesBufError>

Collects properties from an iterator into a new buffer.

Errors

Returns PropertiesBufError if any property’s identifier is not in P::ALLOWED or the result would exceed Vbi::MAX.

Methods from Deref<Target = Properties<P>>

pub const EMPTY: &'static Self

pub fn is_empty(&self) -> bool

Returns true if there are no properties.

pub fn as_bytes(&self) -> &[u8]

Returns the raw bytes of the properties section.

pub fn iter(&self) -> PropertiesIter<'_>

Returns an iterator over the properties in this section.

pub fn find(&self, id: PropertyId) -> Option<Property<'_>>

Find the first occurrence of a property by identifier.

This is a linear scan over all properties.

pub fn collect_ids(&self) -> PropertyIdSet

Collects the set of property ids present in this section.

The word “collect” is used to indicate that this is a linear scan over all properties.

fn len_vbi(&self) -> Vbi

pub fn encoded_len(&self) -> usize

Returns the number of bytes needed to encode this properties section including the leading variable byte integer length prefix.

pub fn encode(&self, w: &mut Writer<'_>) -> Result<(), EncodeError>

Encodes this properties section into the writer, including the leading variable byte integer length prefix.

Errors

Returns EncodeError if the writer does not have enough capacity.